@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 import os, sys, time
 from geonameszip import update
 
@@ -17,9 +17,15 @@ try:
 except OSError:
   created_time = now - 90000
 
+# maybe python2.7 backwards?
+try:
+  input = raw_input
+except:
+  pass
+
 # only download if it's greater than a day
 if now - created_time > 86400 and force is False:
-  do_import = raw_input('This will download the latest zip file from geonames and import it into the default zipcode database. Please do not abuse this since geonames offers this data _for free_. Continue? Y/n')
+  do_import = input('This will download the latest zip file from geonames and import it into the default zipcode database. Please do not abuse this since geonames offers this data _for free_. Continue? Y/n')
 elif force is False:
   do_import = 'n'
   print('Previously downloaded file is less than 24 hours old -- using it.')
